close all; clear all; %#ok<CLSCR>
% This version made January 2016 by Christian Jrgensen and Mikael van Deurs.
% Model for diet and habitat choice for a cod in resund building gonads.
% ARA is moved every week from lipid stores to gonads, and influences fitness at time of spawning.
% There is a spin-up prior to week T-30 where everything is constant, also temperature.
% Some energy is drained every week for growth, except the last four weeks before spawning.

%% Parameters
% Resolution
Timesteps = 70; % number of weeks, starting roughly 1 August (initial state) and lasting through 1 April (spawning)
maxL = 11; % Number of categories for liver weight (from 0 to 10 is eleven categories)
maxP = 11; % Number of categories for muscle (protein store) weight
maxB = 11; % Number of categories for foraging behaviour
maxARA = 11; % Number of categories for ARA
maxGA = 11;  % Number of categories for gonad ARA
% The fish studied
Length = 55; %55; %cm
Structural_K = 0.85;  % Fulton's condition factor of lean cod with no stores (only structural mass)
StructuralWeight = (Structural_K/1E2)*(Length^3); % g
TargetGonadWeight = 0.2*StructuralWeight; % (g)
maxLweight = 0.2*StructuralWeight;  %Max weight of liver (lipid store) (min is 0)
maxPweight = 0.5*StructuralWeight; %Max weight of muscle (protein store) (min is 0)
minBehaviour = 0.;  %Was 1, changed to 0, could not remember why there should be a lower constraint.
maxBehaviour = 15.;
maxARAweight = maxLweight*0.07; % grams
GonadProteinProportion = 0.7;    % proportion protein content, by energy. The remainder is lipids. From Kjesbu et al. 1991 CJFAS
maxGAweight = TargetGonadWeight*(1-GonadProteinProportion)*0.07;  %Max 7% in lipid fraction of gonads
% Mikael used K=0.8 and L^3 to standardize GSI and HSI (resembling using gutted weight but correcting for more of individual variation)

% Environment 
Temp_std = 10.;  %Standard temperature at which foraging behaviour of 1 equals 1 SMR of structural weight 
Temp(1:Timesteps,1:2) = 0;  
StartTemp = 10;
EndTemp = 10;
Temp(Timesteps-29:Timesteps,1) = StartTemp-((Timesteps-29:Timesteps)-(Timesteps-29))*(StartTemp-EndTemp)/(29);  % (deg C) for now set constant to value of T.  
Temp(Timesteps-29:Timesteps,2) = StartTemp-((Timesteps-29:Timesteps)-(Timesteps-29))*(StartTemp-EndTemp)/(29);  % (deg C) for now set constant to value of T.  
Temp(1:Timesteps-30,:) = StartTemp;

Temp(1:Timesteps,1:2) = 6;
Temp(1:Timesteps-5,1:2) = 8;
Temp(1:Timesteps-10,1:2) = 9;
Temp(1:Timesteps-15,1:2) = 10;
Temp(1:Timesteps-20,1:2) = 10;
Temp(1:Timesteps-25,1:2) = 10;
Temp(1:Timesteps-30,1:2) = 9;
Temp(1:Timesteps-35,1:2) = 8;
Temp(1:Timesteps-40,1:2) = 7;
Temp(1:Timesteps-45,1:2) = 6;
Temp(1:Timesteps-50,1:2) = 5;
Temp(1:Timesteps-55,1:2) = 6;
Temp(1:Timesteps-60,1:2) = 7;
Temp(1:Timesteps-65,1:2) = 8;

FoodPresence(1:Timesteps,1:2) = 1.; 
%FoodPresence(1:Timesteps,2  ) = 0.8;
%FoodPresence(1:Timesteps,2  ) = 0.33;%If 0.8: The cod have to work harder to find same amount of energy in crabs 
FoodPresence(1:Timesteps-25,2) = 0.3; %Until week 25 before spawning only some fish in pelagic habitat...
%FoodPresence(45:Timesteps,2) = 0.3;


%FoodPresence(Timesteps-4:Timesteps,1:2) = 0; %... and when herring have left, close to spawning
%FoodPresence(Timesteps-5:Timesteps,1) = 1;
%FoodPresence(1:Timesteps,1:2) = 1.; 

%FoodPresence(1:Timesteps,2) = 0.;%Food always present
%FoodPresence(1:Timesteps-25,2) = 0.25;%Until week 27 before spawning only some fish in pelagic habitat
%FoodPresence(Timesteps-8:Timesteps,2) = 0.25;
%FoodPresence(1:Timesteps,1) = 1.; 
%FoodPresence(1:Timesteps,2) = 1.; 


% Prey                 1:crabs  2:herring
LipidContent        = [  0.30  ,  0.70   ];  % proportion of energy
ProteinContent      = [  0.70  ,  0.30   ];  % proportion of energy
Digestibility       = [ -0.001, -0.0024 ];  % constraint on digestion rate
ARAContent          = [  0.07  ,  0.005  ];  % ARA content (proportion of lipds that is ARA)
PreyEnergyDensity   = [  2000,   5000  ];  % Energy content in J g-1
DigestionEfficiency = [  0.75  ,  0.75   ];  % Proportion of energy content ingested that is absorbed. Same for all prey/habitats. (SDA is later.)
VariableForagingEff = [  0     ,  0     ];  % herring -1, When preying on herring, the cod is less efficient if fat. Coefficient of -1 is dervied from Mikael's excel sheet. Larger negative number will reduce foraging efficiency more.
%ARAContent(1) = ARAContent(2);

MaxGutSize             =  0.1;    % Proportion of structural weight
ProteinEnergyDensity   = 4000;    % (J/g) energy density in protein stores = muscle tissue (per wet weight)
LipidEnergyDensity     = 20000;    % (J/g) energy density in lipid stores = liver (per wet weight)
GonadEnergyDensity     = 5000;    % (J/g) energy density of gonads (per wet weight)
GonadBiosynthesisCost  = 1.00;    % in proportion of energy laid down as new gonad tissue
MetabolicLipids(1:Timesteps) = 0.6;    % Proportion of energy taken from lipids if available, rest from proteins. Ca 0.70 accoreding to Kieffer et al. 1998 J Exp Biol
ARAeffect_intercept = 1; % -0.005; <- using this value will increase motivation to build ARA stores %Default = 0, Calculated from viable eggs measured from cod on different ARA diets, Mikael has the paper. 
ARAeffect_slope = 0;       %...Used Kjesbu et al. 1996 for ca 400 eggs spawned per g female body mass.

%Jeg har kjrt med parametre for ARA som er slik: 
%   ARA-effekt P:
%ARAeffect_intercept = 0;
%ARAeffect_slope = 1; 
%   ARA-effekt AV:
%ARAeffect_intercept = 1;
%ARAeffect_slope = 0;





ProteinLossToGrowth(1:Timesteps) = (1/1E2)*(Length^3)*(1.005^7-1)*ProteinEnergyDensity*0.5; % g some proteins required for continuous growth...
ProteinLossToGrowth(Timesteps-2:Timesteps) = 0.; % g ...except 2 last weeks
%ProteinLossToGrowth(1:Timesteps) = 0.; % 

% Mortality
Fishing = 0.0;                             %(y-1) Annual mortality rate from fishing 
M       = 0.02;                          %0.05   %(y-1) Annual mortality rate that is independent of strategies
O2M_coeff = 0.2; O2M_exp = 3;             %(y-1, dim-less) Mortality resulting from constrained oxygen budget
ForagingM_coeff = 0.015 ; ForagingM_exp = 2; %(y-1, dim-less) Mortality resulting from foraging behaviour
ConditionMax = 1.0; ConditionExp = 3;
ConditionM_coeff = 0.05;

% Foraging mortality does not depend on habitat, but is related to intake in Joules (increases with increasing foraging). For the same mortality, a cod can eat
% 250g crabs or 100g herring - is this realistic? DO WE NEED TO INTRODUCE PARAMETER TO RUN SENSITIVITY ANALYSIS OF THIS ASSUMPTION? ************
% What about size-dependent mortality? Since no growth, we use only fixed M.
% What about condition-dependent mortality due to drag/swimming/escape ? Skip for now? ******ADDED*******

% Bioenergetics parameters
CostOfForaging = 0.15;           % Default 0.15; Proportion of ingested food that goes towards the behaviour of finding the food
SDACoeff = 0.17;                 % Proportion of ingested food that is SDA
SDA_P = 0.14;                    % From Mikael's notebook
SDA_L = 0.04;    %0.04                % From Mikael's notebook
SMR_exp = 0.75;                  % This is the SMR exponent applied in this model

GonadGrowthLastTwoWeeks = 0.4;
GonadGrowthSeason = 27;  %Default is 27 
GonadGrowthProportion(1:Timesteps) = 0;  %Just reset to zero first
GonadGrowthProportion(Timesteps-2:Timesteps-1) = GonadGrowthLastTwoWeeks/2; % The last two weeks a lot of gonad mass is laid down
GonadGrowthProportion(Timesteps-GonadGrowthSeason:Timesteps-3) = (1-GonadGrowthLastTwoWeeks)/(GonadGrowthSeason-2);  %grow a constant unit mass for the 25 weeks befor that

%% Variables with values defined more intricately from literature or from above
% With values defined from above

% Standard metabolic rate from Clarke & Johnston 1999
SMR_exp_CJ99 = 0.80;
SMR_coeff_CJ99 = exp(-5.43) * 434 * 24 * 7;  %J g-1 w-1, Converted from values given in paper, p 895

%Correction acording to new expponent
SMR_coeff_singlevalue = SMR_coeff_CJ99 * (1000^(SMR_exp_CJ99-SMR_exp));  % Coefficient changed by standardization to a 1 kg fish

%SMR at a standard temperature (for scaling foraging intake)
SMR_std = exp(15.7-(5.02.*1000./(Temp_std+273.15))) .* 434 .* 24 .* 7;  % J ind-1 w-1 for a 50g fish SMR of Structural mass at standard temperature, line 1 ...
SMR_std = SMR_std/(50^SMR_exp);                                         % J g-1 w-1 ... line 2
SMR_std = SMR_std * (StructuralWeight^SMR_exp);
%Temperature effect on SMR
SMR_TempFunction(:,:) = exp(15.7-(5.02.*1000./(Temp(:,:)+273.15))) .* 434 .* 24 .* 7;  % (J w-1) was measured for a 50g fish
SMR_TempFunction(:,:) = SMR_TempFunction(:,:)./(50.^SMR_exp); % Multiplicative scaling of SMR around 1.0, one value per timestep. 
SMR_coeff(:,:) = SMR_TempFunction(:,:);                                                %Coefficient in SMR calculations, One value for each timestep depending on temperature

%AMR_exp_Cetal = 0.82;  %From Claireaux et al. 2000, cod, exponent was originally 0.82
AMR_coeff_Claireaux = 1.0-exp(-0.035*100+0.34);  % first part of AMR in eq. 9
AMR_TempFunction(:,:)  = (17.29.*(Temp(:,:).^(-0.015.*Temp(:,:)+1.062))) + 30.01;  %second part of eq. 9 - one value per timestep according to temperature.
AMR_coeff(:,:) = AMR_coeff_Claireaux * AMR_TempFunction(:,:); %(mgO2 kg-1 h-1) AMR as in Claireaux et al. first and second part of eq. 9 multiplied.
AMR_coeff(:,:) = AMR_coeff(:,:) * 14.013 * 24 *7; % J kg-1 w-1 % Using 1mg O2 = 14.013 J
AMR_exp = SMR_exp;  %Use same exponent for AMR as for SMR
AMR_coeff(:,:) = AMR_coeff(:,:) / (1000^AMR_exp);  %Changed exponent by standardization to a 1 kg fish


%% Variables declared for faster execution
Prey = round(0.);   % 1: crabs, 2: herring

GonadGrowth = 0.; GonadWeight = 0.; Lweight = 0.; Pweight = 0.; TotalWeight = 0.; MRWeight = 0.; %g (or g per week)

%Strategy matrix
ForagingRate(1:maxB,1:2) = 0.; ForagingM(1:maxB,1:2) = 0.;
for H = 1:2;  %NEED TO THINK ABOUT HABITAT OR DIET DIFFERENCES AND IMPLEMENT HERE ******************Maybe also in CostOfForaging
 ForagingRate(:,H)=minBehaviour:((maxBehaviour-minBehaviour)/(maxB-1)):maxBehaviour;  %Effect of foraging behaviour, in terms of multiples of SMR eaten (at Temp_std). Can vary between habitats
 ForagingM(:,H) = ForagingM_coeff.*(ForagingRate(:,H).^ForagingM_exp); %Mortality rate resulting from foraging behaviour, can vary between habitats
end
%Other optimization matrices
Intake(1:maxB,1:2) = 0.; Intake_L(1:maxB,1:2) = 0.; Intake_P(1:maxB,1:2) = 0.;
LEnergy(1:maxB,1:2) = 0.; PEnergy(1:maxB,1:2) = 0.; 
NewPweight(1:maxB,1:2) = 0.; NewLweight(1:maxB,1:2) = 0.; 
SDA(1:maxB,1:2) = 0.; AMR(1:maxB,1:2) = 0.; EnergeticCostOfForaging(1:maxB,1:2) = 0.;
Fitness(1:maxB,1:2) = 0.; FitnessSuccess(1:maxB,1:2) = 0.; Strategy(1:2,1:maxGA,1:maxARA,1:maxP,1:maxL,1:Timesteps) = 0.; 
ARAweight = 0.; NewARAweight(1:maxB,1:2) = 0.; NewGAweight(1:maxB,1:2) = 0.; ConditionM(1:maxB,1:2) = 0.;

%% Optimization
RV(1:maxGA,1:maxARA,1:maxP,1:maxL,Timesteps) = TargetGonadWeight;   
RV(:,:,:,:,1:Timesteps-1) = 0.;
t = Timesteps;
fitnesswhilerunning = figure();
fitnesswhilerunning.Name = ['Timestep = ', num2str(t)];
plot1 = subplot(2,2,1);
surf(plot1, squeeze(RV(4,2,:,:,t))); 
plot1.XLabel.String = 'Lipid';
plot1.YLabel.String = 'Protein';
%plot1.CameraPosition = [-30, -70, 15];
plot2 = subplot(2,2,2);
surf(plot2, squeeze(RV(:,:,5,5,t))); 
plot2.XLabel.String = 'ARA';
plot2.YLabel.String = 'Gonad ARA';
%plot2.CameraPosition = [-30, -70, 15];
plot3 = subplot(2,2,3);
surf(plot3, squeeze(RV(5,:,5,:,t))); 
plot3.XLabel.String = 'Lipid';
plot3.YLabel.String = 'ARA';
%plot3.CameraPosition = [-30, -70, 15];
plot4 = subplot(2,2,4);
surf(plot4, squeeze(RV(5,:,:,5,t))); 
plot4.XLabel.String = 'Protein';
plot4.YLabel.String = 'ARA';
%plot4.CameraPosition = [-30, -70, 15];

for t = Timesteps-1:-1:1  %Loop over timesteps backwards
 disp(['t=',num2str(t)]);
 RRV = RV(:,:,:,:,t+1);  %Transfer fitness matrices from time-step to timestep, Residual Reproductive Value
 GonadGrowth = GonadGrowthProportion(t) * TargetGonadWeight * GonadEnergyDensity; % (J) Joules of gonads laid down this week
 GonadGrowth_P = GonadGrowth *    GonadProteinProportion ;  %J gonad growth from proteins
 GonadGrowth_L = GonadGrowth * (1-GonadProteinProportion);  %J gonad growth from lipids
 GonadGrowthCost = (GonadGrowth * GonadBiosynthesisCost);   %J, cost of building the gonad tissue.
 GonadWeight = sum(GonadGrowthProportion(1:max(1,t-1))) * TargetGonadWeight; %g  Mass og gonads at beginning of time-step
 NewGonadWeight = sum(GonadGrowthProportion(1:t)) * TargetGonadWeight; %g  Mass og gonads at end of time-step
 SDA(:,:) = 0.;
 for H = 1:2
  MaxEvacuationRate(H) = -Digestibility(H) .* (Length^1.3) .* exp(0.083*Temp(t,H)*(PreyEnergyDensity(H)^(-0.085))) .* sqrt(MaxGutSize*StructuralWeight); % g/h
  MaxEvacuationRate(H) = MaxEvacuationRate(H) * PreyEnergyDensity(H) * 24 * 7; % J week-1
  EnergeticForagingCostCoeff(:,H) = ForagingRate(:,H) .* CostOfForaging .* SMR_coeff(t,H);  %Same unit as SMR_coeff: J w-1 . Updated with this time-step's temperature for specific habitat
 end
 for L = 1:maxL  %Cycle over values of potential liver size
  Lweight = ((L-1)/(maxL-1))*maxLweight; %g
  for H = 1:2
   Intake(:,H) = min(ForagingRate(:,H) .* SMR_std .* (1 + VariableForagingEff(H) .* ((GonadWeight+Lweight)/StructuralWeight)).*FoodPresence(t,H), MaxEvacuationRate(H));  % Food eaten. J week-1. Only lipid stores and gonads make cod less efficient forager, increased muscle mass has no (positive or negative) effect.
   Intake(:,H) = Intake(:,H) * DigestionEfficiency(H); % J week-1 Energy absorbed.
   Intake_P(:,H) = Intake(:,H) * ProteinContent(H);  %J week-1 Absorption of proteins by white muscle, before SDA
   Intake_L(:,H) = Intake(:,H) * LipidContent(H)  ;  %J week-1 Absorption of lipids by liver, before SDA
   SDA(:,H) = Intake_P(:,H) * SDA_P + Intake_L(:,H) * SDA_L;     %J week-1 SDA for oxygen budget
   Intake_P(:,H) = Intake_P(:,H); %* (1-SDA_P);  %J week-1 Absorption of proteins by white muscle, after SDA has been accounted for
   Intake_L(:,H) = Intake_L(:,H);%* (1-SDA_L);  %J week-1 Absorption of lipids by liver, after SDA has been accounted for
   Intake_ARA(:,H) = Intake_L(:,H) * ARAContent(H)/LipidEnergyDensity;  %g week-1 Absorption of ARA
  end
  for P = 1:maxP  %Cycle over values of potential protein store size
   Pweight = ((P-1)/(maxP-1)) * maxPweight; %g
   LEnergy(:,:) = Lweight * LipidEnergyDensity; %J, total store of lipid energy
   PEnergy(:,:) = Pweight * ProteinEnergyDensity; %J, total store of protein energy
   TotalWeight = StructuralWeight + GonadWeight + Pweight + Lweight; %g
   MRWeight    = StructuralWeight + GonadWeight + Pweight; %g  Liver lipids kept outside
   for H = 1:2   %Loop to make SMR table the same dimensions as other tables.
    SMR(1:maxB,H) = squeeze(SMR_coeff(t,H)) * (        MRWeight^SMR_exp);  %J week-1
    AMR(1:maxB,H) = squeeze(AMR_coeff(t,H)) * (StructuralWeight^AMR_exp);  %J week-1
   end
   EnergeticCostOfForaging(:,:)  = EnergeticForagingCostCoeff(:,:).*(MRWeight.^SMR_exp); %J w-1. Energetic cost of foraging Can be taken from lipids
   TotalMRrequirement(:,:) = SMR(:,:) + EnergeticCostOfForaging(:,:) + GonadGrowthCost + SDA(:,:);  %How much energy is needed?
   TotalO2requirement(:,:) = TotalMRrequirement(:,:) + SDA(:,:);  %the energy of SDA was subtracted in intake, but will affect respiration budget
   FitnessSuccess(:,:) = (LEnergy(:,:)>GonadGrowth_L);  % Death if not enough lipids for gonad biosynthesis
   TotalLrequirement(:,:)  = TotalMRrequirement(:,:) * MetabolicLipids(t) + GonadGrowth_L;  %J, energy that can be taken from lipids if available, metabolism plus gonad growth
   TotalLrequirement(:,:)  = min(TotalLrequirement(:,:), LEnergy(:,:));           %J lipid requirement constrained by what is available 
   TotalPrequirement(:,:)  = (TotalMRrequirement(:,:) + GonadGrowth_L- TotalLrequirement(:,:)) + GonadGrowth_P + ProteinLossToGrowth(t);  %J, energy that must be taken from proteins, metabolism plus gonad growth
   
   %New energy stores
   FitnessSuccess(:,:) = min(FitnessSuccess(:,:), (PEnergy(:,:)>TotalPrequirement(:,:)));   % Death also if not enough proteins for metabolic rate
   
   %Oxygen budgets
   O2M(:,:) = O2M_coeff.*(TotalO2requirement(:,:)./AMR(:,:)).^O2M_exp; %General Mortality Cost - Exponent of 3 or 4
   
   %Survival
   ConditionM(:,:) = ConditionM_coeff*((100.*(TotalWeight(:,:))./(Length^3))./ConditionMax).^ConditionExp;  %Mortality increasing with conditon, similar to M at K=ConditionMax
   Survival(:,:) = exp(-(M + ForagingM(:,:) + ConditionM(:,:) + O2M(:,:) + Fishing)/52);  % per week

   %State changes
   LEnergy(:,:) = max(LEnergy(:,:) + Intake_L(:,:) - TotalLrequirement(:,:),0);  %constrained not to be negative, taken care of a few lines above
   PEnergy(:,:) = PEnergy(:,:) + Intake_P(:,:) - TotalPrequirement(:,:);         %If negative, fitness will be set to zero below
   NewLweight(:,:) = LEnergy(:,:)/LipidEnergyDensity;    %g   Remaining energy in store converted to weight of organ
   NewPweight(:,:) = PEnergy(:,:)/ProteinEnergyDensity;  %g   Remaining energy in store converted to weight of organ
   %interpolation
   intL(:,:) = max(1, min(floor(NewLweight(:,:).*(maxL-1)./maxLweight)+1, maxL-1));  % integer and decimal parts for interpolation
   dL(:,:) = min(1.,(NewLweight(:,:).*((maxL-1)./maxLweight)+1)-intL);
   intP(:,:) = max(1, min(floor(NewPweight(:,:).*(maxP-1)./maxPweight)+1, maxP-1));
   dP(:,:) = min(1.,(NewPweight(:,:).*((maxP-1)./maxPweight)+1)-intP);

   for ARA = 1:maxARA 
    ARAweight = (double(ARA-1)/double(maxARA-1))*maxARAweight;  %grams, taken from state category
    if Lweight>1e-6
     ARAconcentration = (ARAweight/Lweight);
    else
     ARAconcentration = 0.;
    end
    MetabolizedARA(:,:)  = ARAconcentration*(TotalLrequirement(:,:)-GonadGrowth_L)/LipidEnergyDensity; %Concentration of ARA in lipid tissue, multiplied with lipid mass used for metabolism
    ARAflowtoGonads = ARAconcentration*(GonadGrowth_L/LipidEnergyDensity); %Concentration of ARA in lipid tissue, multiplied with lipid mass transferred to gonads
    %Fitness interpolation
    NewARAweight(:,:) = ARAweight + Intake_ARA(:,:) - MetabolizedARA(:,:) - ARAflowtoGonads;   %grams
    intARA(:,:) = max(1, min(floor(NewARAweight(:,:).*(maxARA-1)./maxARAweight)+1, maxARA-1));  % integer and decimal parts for interpolation
    dARA(:,:) = min(1.,(NewARAweight(:,:).*((maxARA-1)./maxARAweight)+1)-intARA);

    for GA = 1:maxGA %gonad ARA
     GAweight = (double(GA-1)/double(maxGA-1))*maxGAweight;  %grams, taken from state category
     NewGAweight = GAweight + ARAflowtoGonads;
     intGA = max(1, min(floor(NewGAweight*(maxGA-1)/maxGAweight)+1, maxGA-1));  % integer and decimal parts for interpolation
     dGA = min(1.,(NewGAweight*((maxGA-1)./maxGAweight)+1)-intGA);
     for H = 1:2;  %Two habitats/diets
      for B = 1:maxB;
       Fitness(B,H) =    dGA *   dARA(B,H) *   dP(B,H) *   dL(B,H) * RRV(intGA+1,intARA(B,H)+1,intP(B,H)+1,intL(B,H)+1) + ...   %Residual reproductive value = future fitness
                      (1-dGA)*   dARA(B,H) *   dP(B,H) *   dL(B,H) * RRV(intGA  ,intARA(B,H)+1,intP(B,H)+1,intL(B,H)+1) + ...
                         dGA *(1-dARA(B,H))*   dP(B,H) *   dL(B,H) * RRV(intGA+1,intARA(B,H)  ,intP(B,H)+1,intL(B,H)+1) + ...
                      (1-dGA)*(1-dARA(B,H))*   dP(B,H) *   dL(B,H) * RRV(intGA  ,intARA(B,H)  ,intP(B,H)+1,intL(B,H)+1) + ...
                         dGA *   dARA(B,H) *(1-dP(B,H))*   dL(B,H) * RRV(intGA+1,intARA(B,H)+1,intP(B,H)  ,intL(B,H)+1) + ...
                      (1-dGA)*   dARA(B,H) *(1-dP(B,H))*   dL(B,H) * RRV(intGA  ,intARA(B,H)+1,intP(B,H)  ,intL(B,H)+1) + ...
                         dGA *(1-dARA(B,H))*(1-dP(B,H))*   dL(B,H) * RRV(intGA+1,intARA(B,H)  ,intP(B,H)  ,intL(B,H)+1) + ...
                      (1-dGA)*(1-dARA(B,H))*(1-dP(B,H))*   dL(B,H) * RRV(intGA  ,intARA(B,H)  ,intP(B,H)  ,intL(B,H)+1) + ...
                         dGA *   dARA(B,H) *   dP(B,H) *(1-dL(B,H))* RRV(intGA+1,intARA(B,H)+1,intP(B,H)+1,intL(B,H)  ) + ...
                      (1-dGA)*   dARA(B,H) *   dP(B,H) *(1-dL(B,H))* RRV(intGA  ,intARA(B,H)+1,intP(B,H)+1,intL(B,H)  ) + ...
                         dGA *(1-dARA(B,H))*   dP(B,H) *(1-dL(B,H))* RRV(intGA+1,intARA(B,H)  ,intP(B,H)+1,intL(B,H)  ) + ...
                      (1-dGA)*(1-dARA(B,H))*   dP(B,H) *(1-dL(B,H))* RRV(intGA  ,intARA(B,H)  ,intP(B,H)+1,intL(B,H)  ) + ...
                         dGA *   dARA(B,H) *(1-dP(B,H))*(1-dL(B,H))* RRV(intGA+1,intARA(B,H)+1,intP(B,H)  ,intL(B,H)  ) + ...
                      (1-dGA)*   dARA(B,H) *(1-dP(B,H))*(1-dL(B,H))* RRV(intGA  ,intARA(B,H)+1,intP(B,H)  ,intL(B,H)  ) + ...
                         dGA *(1-dARA(B,H))*(1-dP(B,H))*(1-dL(B,H))* RRV(intGA+1,intARA(B,H)  ,intP(B,H)  ,intL(B,H)  ) + ...
                      (1-dGA)*(1-dARA(B,H))*(1-dP(B,H))*(1-dL(B,H))* RRV(intGA  ,intARA(B,H)  ,intP(B,H)  ,intL(B,H)  ) ;
      end
     end
    
     Fitness(:,:) = squeeze( FitnessSuccess(:,:) .* Survival(:,:) .* Fitness(:,:) );  %Reprod. at end of year, gonads added to residual fitness, everything discounted by survival
     %ADD EFFECTS OF ARA
     if (t == Timesteps-1)
      ARAeffect = max(0,ARAeffect_intercept + ARAeffect_slope*NewGAweight/TargetGonadWeight);
      Fitness(:,:) = ARAeffect * Fitness(:,:);
     end
  
     %Find optimal strategy
     [OptBFitness,OptB] = max(Fitness);  %First find optimal B (for each H)- matlab stores optimal fitness and index of optimal fitness in the two arrays
     [OptFitness, OptH] = max(OptBFitness,[],2);  %Then find optimal B as maximum of the many values from previous line.
     RV(GA,ARA,P,L,t) = OptFitness; %Optimal fitness (States age and lenght as well as the environment)
     if OptB(OptH) == 1
      Strategy(1,GA,ARA,P,L,t) = maxB;
     else
      Strategy(1,GA,ARA,P,L,t) = OptB(OptH); %Optimal foraging behaviour
     end
     Strategy(2,GA,ARA,P,L,t) = OptH; %Optimal habitat/diet choice
    end % gonad ARA
   end %ARA
  end %P
 end %L 
 if t > Timesteps-GonadGrowthSeason
  GonadARAplotvalue = 5;
  GonadARAtext = '';
 else
  GonadARAplotvalue = 1;
  GonadARAtext = ' (for Gonad ARA only value 0 is in use at timesteps <43).';
 end
 
 fitnesswhilerunning.Name = ['Timestep = ', num2str(t), GonadARAtext];
 surf(plot1, squeeze(RV(GonadARAplotvalue,2,:,:,t))); 
 plot1.XLabel.String = 'Lipid';
 plot1.YLabel.String = 'Protein';
 plot1.XLim = [1 maxL];
 plot1.YLim = [1 maxP];
 surf(plot2, squeeze(RV(:,:,5,5,t))); 
 plot2.XLabel.String = 'ARA';
 if t > Timesteps-GonadGrowthSeason
  plot2.YLabel.String = 'Gonad ARA';
 else
  plot2.YLabel.String = {'Gonad ARA', '(only 0 in use)'};
 end  
 plot2.XLim = [1 maxARA];
 plot2.YLim = [1 maxGA];
 surf(plot3, squeeze(RV(GonadARAplotvalue,:,5,:,t))); 
 plot3.XLabel.String = 'Lipid';
 plot3.YLabel.String = 'ARA';
 plot3.XLim = [1 maxL];
 plot3.YLim = [1 maxARA];
 surf(plot4, squeeze(RV(GonadARAplotvalue,:,:,5,t))); 
 plot4.XLabel.String = 'Protein';
 plot4.YLabel.String = 'ARA';
 plot4.XLim = [1 maxP];
 plot4.YLim = [1 maxARA];
 drawnow;
end %t


%% FORWARD SIMULATION

%declare arrays
iForagingRate(1:Timesteps) = 0.; iH(1:Timesteps) = 0.; iIntake(1:Timesteps) = 0.; iIntake_P(1:Timesteps) = 0.; iIntake_L(1:Timesteps) = 0.;
iLEnergy(1:Timesteps) = 0.; iPEnergy(1:Timesteps) = 0.; iMRWeight(1:Timesteps) = 0.; 
iPweight(1:Timesteps) = 0.; iLweight(1:Timesteps) = 0.; iARAweight(1:Timesteps) = 0.; iSurvival(1:Timesteps) = 0.; iSDA(1:Timesteps) = 0.; iSMR(1:Timesteps) = 0.; 
iGonadGrowth(1:Timesteps) = 0.; iGonadGrowth_P(1:Timesteps) = 0.; iGonadGrowth_L(1:Timesteps) = 0.; iGonadGrowthCost(1:Timesteps) = 0.; 
iGonadWeight(1:Timesteps) = 0.; iEnergeticCostOfForaging(1:Timesteps) = 0.; iTotalMRrequirement(1:Timesteps) = 0.; iTotalO2requirement(1:Timesteps) = 0.; 
iTotalLrequirement(1:Timesteps) = 0.; iTotalLrequirement(1:Timesteps) = 0.; iTotalPrequirement(1:Timesteps) = 0.; iIntake_ARA(1:Timesteps) = 0.;
iAMR(1:Timesteps) = 0.; iO2M(1:Timesteps) = 0.; iForagingM(1:Timesteps) = 0.; iSMR(1:Timesteps) = 0.; iMaxEvacuationRate(1:Timesteps) = 0.; 
iMetabolizedARA(1:Timesteps) = 0.; iARAflowtoGonads(1:Timesteps) = 0.; iGAweight(1:Timesteps) = 0.; iARAconcentration(1:Timesteps) = 0.;
iTotalWeight(1:Timesteps) = 0.; iintGA(1:Timesteps) = 0.; iintARA(1:Timesteps) = 0.; iintP(1:Timesteps) = 0.; iintL(1:Timesteps) = 0.;
iConditionM(1:Timesteps) = 0.;

%Initial states
iPweight(1) = 0.2*maxPweight;
iPEnergy(1) = iPweight(1)*ProteinEnergyDensity;
iLweight(1) = 0.1*maxLweight;%0.2*maxLweight;
iLEnergy(1) = iLweight(1)*LipidEnergyDensity;
iARAweight(1) = ARAContent(2)*iLweight(1); %0.;
iGAweight(1) = 0.; %gonad ARA weight
iSurvival(1) = 1;
iGonadWeight(1) = 0.;

for t = 1:Timesteps-1
  iintL(t) = max(1, min(floor(iLweight(t)*(maxL-1)/maxLweight)+1, maxL-1));  % integer and decimal parts for interpolation
  idL = max(0, min((iLweight(t)*((maxL-1)/maxLweight)+1)-iintL(t),1));
  iintP(t) = max(1, min(floor(iPweight(t)*(maxP-1)/maxPweight)+1, maxP-1));
  idP = max(0,min((iPweight(t)*((maxP-1)/maxPweight)+1)-iintP(t),1));
  iintARA(t) = max(1, min(floor(iARAweight(t)*(maxARA-1)/maxARAweight)+1, maxARA-1));  % integer and decimal parts for interpolation
  idARA = max(0,min((iARAweight(t)*((maxARA-1)/maxARAweight)+1)-iintARA(t),1));
  iintGA(t) = max(1, min(floor(iGAweight(t)*(maxGA-1)/maxGAweight)+1, maxGA-1));  % integer and decimal parts for interpolation
  idGA = max(0,min((iGAweight(t)*((maxGA-1)/maxGAweight)+1)-iintGA(t),1));
  iForagingRate(t) =     idGA *   idARA *   idP *   idL * Strategy(1,iintGA(t)+1,iintARA(t)+1,iintP(t)+1,iintL(t)+1,t) + ...   %finds optimal foraging rate from optimal strategy matrix, decimal number
                      (1-idGA)*   idARA *   idP *   idL * Strategy(1,iintGA(t)  ,iintARA(t)+1,iintP(t)+1,iintL(t)+1,t) + ...
                         idGA *(1-idARA)*   idP *   idL * Strategy(1,iintGA(t)+1,iintARA(t)  ,iintP(t)+1,iintL(t)+1,t) + ...
                      (1-idGA)*(1-idARA)*   idP *   idL * Strategy(1,iintGA(t)  ,iintARA(t)  ,iintP(t)+1,iintL(t)+1,t) + ...  
                         idGA *   idARA *(1-idP)*   idL * Strategy(1,iintGA(t)+1,iintARA(t)+1,iintP(t)  ,iintL(t)+1,t) + ...   
                      (1-idGA)*   idARA *(1-idP)*   idL * Strategy(1,iintGA(t)  ,iintARA(t)+1,iintP(t)  ,iintL(t)+1,t) + ...
                         idGA *(1-idARA)*(1-idP)*   idL * Strategy(1,iintGA(t)+1,iintARA(t)  ,iintP(t)  ,iintL(t)+1,t) + ...
                      (1-idGA)*(1-idARA)*(1-idP)*   idL * Strategy(1,iintGA(t)  ,iintARA(t)  ,iintP(t)  ,iintL(t)+1,t) + ...
                         idGA *   idARA *   idP *(1-idL)* Strategy(1,iintGA(t)+1,iintARA(t)+1,iintP(t)+1,iintL(t)  ,t) + ...
                      (1-idGA)*   idARA *   idP *(1-idL)* Strategy(1,iintGA(t)  ,iintARA(t)+1,iintP(t)+1,iintL(t)  ,t) + ...
                         idGA *(1-idARA)*   idP *(1-idL)* Strategy(1,iintGA(t)+1,iintARA(t)  ,iintP(t)+1,iintL(t)  ,t) + ...
                      (1-idGA)*(1-idARA)*   idP *(1-idL)* Strategy(1,iintGA(t)  ,iintARA(t)  ,iintP(t)+1,iintL(t)  ,t) + ...  
                         idGA *   idARA *(1-idP)*(1-idL)* Strategy(1,iintGA(t)+1,iintARA(t)+1,iintP(t)  ,iintL(t)  ,t) + ...   
                      (1-idGA)*   idARA *(1-idP)*(1-idL)* Strategy(1,iintGA(t)  ,iintARA(t)+1,iintP(t)  ,iintL(t)  ,t) + ...
                         idGA *(1-idARA)*(1-idP)*(1-idL)* Strategy(1,iintGA(t)+1,iintARA(t)  ,iintP(t)  ,iintL(t)  ,t) + ...
                      (1-idGA)*(1-idARA)*(1-idP)*(1-idL)* Strategy(1,iintGA(t)  ,iintARA(t)  ,iintP(t)  ,iintL(t)  ,t) ;  
  iH(t)            =     idGA *   idARA *   idP *   idL * Strategy(2,iintGA(t)+1,iintARA(t)+1,iintP(t)+1,iintL(t)+1,t) + ...   %finds optimal habitat/diet from optimal strategy matrix, integer (can only be in one place)
                      (1-idGA)*   idARA *   idP *   idL * Strategy(2,iintGA(t)  ,iintARA(t)+1,iintP(t)+1,iintL(t)+1,t) + ...
                         idGA *(1-idARA)*   idP *   idL * Strategy(2,iintGA(t)+1,iintARA(t)  ,iintP(t)+1,iintL(t)+1,t) + ...
                      (1-idGA)*(1-idARA)*   idP *   idL * Strategy(2,iintGA(t)  ,iintARA(t)  ,iintP(t)+1,iintL(t)+1,t) + ...  
                         idGA *   idARA *(1-idP)*   idL * Strategy(2,iintGA(t)+1,iintARA(t)+1,iintP(t)  ,iintL(t)+1,t) + ...   
                      (1-idGA)*   idARA *(1-idP)*   idL * Strategy(2,iintGA(t)  ,iintARA(t)+1,iintP(t)  ,iintL(t)+1,t) + ...
                         idGA *(1-idARA)*(1-idP)*   idL * Strategy(2,iintGA(t)+1,iintARA(t)  ,iintP(t)  ,iintL(t)+1,t) + ...
                      (1-idGA)*(1-idARA)*(1-idP)*   idL * Strategy(2,iintGA(t)  ,iintARA(t)  ,iintP(t)  ,iintL(t)+1,t) + ...
                         idGA *   idARA *   idP *(1-idL)* Strategy(2,iintGA(t)+1,iintARA(t)+1,iintP(t)+1,iintL(t)  ,t) + ...
                      (1-idGA)*   idARA *   idP *(1-idL)* Strategy(2,iintGA(t)  ,iintARA(t)+1,iintP(t)+1,iintL(t)  ,t) + ...
                         idGA *(1-idARA)*   idP *(1-idL)* Strategy(2,iintGA(t)+1,iintARA(t)  ,iintP(t)+1,iintL(t)  ,t) + ...
                      (1-idGA)*(1-idARA)*   idP *(1-idL)* Strategy(2,iintGA(t)  ,iintARA(t)  ,iintP(t)+1,iintL(t)  ,t) + ...  
                         idGA *   idARA *(1-idP)*(1-idL)* Strategy(2,iintGA(t)+1,iintARA(t)+1,iintP(t)  ,iintL(t)  ,t) + ...   
                      (1-idGA)*   idARA *(1-idP)*(1-idL)* Strategy(2,iintGA(t)  ,iintARA(t)+1,iintP(t)  ,iintL(t)  ,t) + ...
                         idGA *(1-idARA)*(1-idP)*(1-idL)* Strategy(2,iintGA(t)+1,iintARA(t)  ,iintP(t)  ,iintL(t)  ,t) + ...
                      (1-idGA)*(1-idARA)*(1-idP)*(1-idL)* Strategy(2,iintGA(t)  ,iintARA(t)  ,iintP(t)  ,iintL(t)  ,t) ;  
  iH(t) = round(iH(t));
  iForagingRate(t) = minBehaviour + (iForagingRate(t)-1)*(maxBehaviour-minBehaviour)/(maxB-1);
  iGonadGrowth(t)    = GonadGrowthProportion(t) * TargetGonadWeight * GonadEnergyDensity; % (J) Joules of gonads laid down this week
  iGonadGrowth_P(t)  = iGonadGrowth(t) *    GonadProteinProportion ;  %J gonad growth from proteins
  iGonadGrowth_L(t)  = iGonadGrowth(t) * (1-GonadProteinProportion);  %J gonad growth from lipids
  iGonadGrowthCost(t)= iGonadGrowth(t) * GonadBiosynthesisCost;       %J, mteabolic cost of building the gonad tissue.
  iGonadWeight(t)    = sum(iGonadGrowth(1:max(1,t-1))) / GonadEnergyDensity; %g  Mass of gonads at beginning of time-step

  iMaxEvacuationRate(t) = -Digestibility(iH(t)) * (Length^1.3) * exp(0.083*Temp(t,iH(t))*(PreyEnergyDensity(iH(t))^(-0.085))) .* sqrt(MaxGutSize*StructuralWeight); % g/h
  iMaxEvacuationRate(t) = iMaxEvacuationRate(t) * PreyEnergyDensity(iH(t)) * 24 * 7; % J week-1
  iIntake(t) = iForagingRate(t) * SMR_std * (1 + VariableForagingEff(iH(t)) * ((iGonadWeight(t)+iLweight(t))/StructuralWeight))*FoodPresence(t,iH(t));  % J w-1 Food eaten. Kept here and not outside loops in case we want to play with time- or habitat-varying preuy availability
  iIntake(t) = min(iIntake(t), iMaxEvacuationRate(t)) * DigestionEfficiency(iH(t));  %Constrain to max evacuation rate and account for digestion efficiency
  iIntake_P(t) = iIntake(t) * ProteinContent(iH(t));  %J week-1 Absorption of proteins by white muscle, before SDA
  iIntake_L(t) = iIntake(t) * LipidContent(iH(t))  ;  %J week-1 Absorption of lipids by liver, before SDA
  iSDA(t) = iIntake_P(t) * SDA_P + iIntake_L(t) * SDA_L;     %J week-1 SDA for oxygen budget
  iIntake_P(t) = iIntake_P(t); %* (1-SDA_P);  %J week-1 Absorption of proteins by white muscle, after SDA has been accounted for
  iIntake_L(t) = iIntake_L(t);%* (1-SDA_L);  %J week-1 Absorption of lipids by liver, , after SDA has been accounted for
  iIntake_ARA(t) = iIntake_L(t) * ARAContent(iH(t))/LipidEnergyDensity;  %g week-1 Absorption of ARA
  iLEnergy(t) = iLweight(t) * LipidEnergyDensity; %J, total store of lipid energy, based on state at time t plus intake
  iPEnergy(t) = iPweight(t) * ProteinEnergyDensity; %J, total store of protein energy plus intake
  iTotalWeight(t) = StructuralWeight + iGonadWeight(t) + iPweight(t) + iLweight(t); %g
  iMRWeight(t) = StructuralWeight + iGonadWeight(t) + iPweight(t); %g  Liver lipids kept outside
  iSMR(t) = SMR_coeff(t,iH(t))*iMRWeight(t)^SMR_exp;  %Requires some equations, AMR too.
  iEnergeticCostOfForaging(t)  = iForagingRate(t) * CostOfForaging * iSMR(t); %J w-1. Energetic cost of foraging Can be taken from lipids
  iTotalMRrequirement(t) = iSMR(t) + iEnergeticCostOfForaging(t) + iGonadGrowthCost(t)+iSDA(t);  %How much energy is needed?
  iTotalO2requirement(t) = iTotalMRrequirement(t) + iSDA(t);  %the energy of SDA was subtracted in intake, but will affect respiration budget
  if iGonadGrowth_L(t) > iLEnergy(t);  % Death if not enough lipids for gonad biosynthesis available throughout the timestep
   iSurvival(t) = 0;
  end
  iTotalLrequirement(t) = iTotalMRrequirement(t) * MetabolicLipids(t) + iGonadGrowth_L(t);  %J, energy that can be taken from lipids if available
  iTotalLrequirement(t) = min(iTotalLrequirement(t), iLEnergy(t));         %J lipid requirement constrained by what is available
  iTotalPrequirement(t) = (iTotalMRrequirement(t) + iGonadGrowth_L(t)- iTotalLrequirement(t)) + iGonadGrowth_P(t) + ProteinLossToGrowth(t);  %J, energy that must be taken from proteins
  if iTotalPrequirement(t) > iPEnergy(t);  % Death also if not enough proteins for metabolic rate
   iSurvival(t) = 0;
  end
  if iLweight(t)>1e-6
   iARAconcentration(t) = iARAweight(t)/iLweight(t);
  else
   iARAconcentration(t) = 0.;
  end
  iMetabolizedARA(t) = iARAconcentration(t)*(iTotalLrequirement(t)-iGonadGrowth_L(t))/LipidEnergyDensity; %g w-1 Concentration of ARA in lipid tissue, multiplied with lipids used for metabolism
  iARAflowtoGonads(t) = iARAconcentration(t)*iGonadGrowth_L(t)/LipidEnergyDensity; %g w-1 Concentration of ARA in lipid tissue, multiplied with lipids transferred to gonads


  %Survival
  iAMR(t) = AMR_coeff(t,iH(t))*(StructuralWeight^AMR_exp);      %J week-1
  iConditionM(t) = ConditionM_coeff*((100*iTotalWeight(t)/(Length^3))/ConditionMax)^ConditionExp;  %Mortality increasing with conditon, similar to M at K=ConditionMax
  iO2M(t) = O2M_coeff*(iTotalO2requirement(t)/iAMR(t))^O2M_exp; %General Mortality Cost - Exponent of 3 or 4
  iForagingM(t) = ForagingM_coeff*(iForagingRate(t)^ForagingM_exp); %Mortality rate resulting from foraging behaviour, can vary between habitats
  iSurvival(t+1) = iSurvival(t) * exp(-(M + iForagingM(t) + iConditionM(t) + iO2M(t) + Fishing)/52);
  
  %New states
  iLEnergy(t+1) = iLEnergy(t) + iIntake_L(t) - iTotalLrequirement(t);                    %constrained not to be negative, taken care of a few lines above
  iPEnergy(t+1) = iPEnergy(t) + iIntake_P(t) - iTotalPrequirement(t);                       %If negative, fitness will be set to zero below
  iPweight(t+1) = min(maxPweight, iPEnergy(t+1) / ProteinEnergyDensity);
  iARAweight(t+1) = min(maxARAweight, iARAweight(t) + iIntake_ARA(t) - iMetabolizedARA(t) - iARAflowtoGonads(t));
  if iLEnergy(t)/LipidEnergyDensity > maxLweight  %if lipid stores are capped because of max constraint, so should ARA stores
   ARAcorrection = maxLweight/(iLEnergy(t)/LipidEnergyDensity);
   iLweight(t+1) = maxLweight;
   iARAweight(t+1) = iARAweight(t+1) * ARAcorrection;
  else
   iLweight(t+1) = min(maxLweight, iLEnergy(t+1) / LipidEnergyDensity);
  end
  iGAweight(t+1) = iGAweight(t) + iARAflowtoGonads(t);
end %t

%% General info for figures
FontName = 'Arial';
FontSize = 12;
TitleWeight = 'bold';
TextWeight = 'normal';
TextLabelFontSize = FontSize;
TickLabelWeight = 'normal';
AxisLabelWeight = 'bold';
AxisLabelFontSize = FontSize;
ContourLabelFontSize = FontSize-2;
PanelLabelFontSize = FontSize;
PanelLabel = {'A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I'};


%% Forward figure
FigForward = figure();
FigRows = 5; FigCols = 2;
figX = 8; figY = 3; distX = 2.0; distY = 1; marginB = 0.6; marginT = 1.1; marginL = 0; marginR = 0.25;
clear('posX', 'posY');
posX(1:FigCols,1:FigRows)=0; posY=posX;
minx = 0; maxx = 35; 
miny = 0; maxy = 1.03;  %*** Per panel
for row = 1:FigRows;
 posX(:,row) = (0:1:FigCols-1)'.*(distX+figX)+distX;  
end
for col = 1:FigCols;
 posY(col,:) = (FigRows-1:-1:0).*(distY+figY)+distY; 
end
posX = posX+marginL; posX = reshape(posX,1,[]); squeeze(posX); posY = posY + marginB;  posY = reshape(posY,1,[]); squeeze(posY);
width = FigCols*(distX+figX) + marginL + marginR;
height = FigRows*(distY+figY) + marginB + marginT;
FigForwardPanels(1:FigRows*FigCols) = 0;  %Handle for panels
set(FigForward,'Name','Forward simulation','Units','centimeters','OuterPosition',[1 1 width height+1.95]);
set(FigForward,'PaperPositionMode','auto','PaperUnits','centimeters','PaperSize',[width height+1.95]);
for panel = 1:FigRows*FigCols
 FigForwardPanels(panel) = subplot(FigRows,FigCols,panel);
 set(FigForwardPanels(panel),'Units','centimeters','Position',[posX(panel) posY(panel) figX figY],'FontSize',FontSize);
 set(FigForwardPanels(panel),'XLim',[0 Timesteps]);
 hold on;
 set(gca,'XTick',0:5:Timesteps);
 if panel == 1
  area(1:Timesteps, iGonadWeight,'FaceColor', 'r', 'LineStyle', 'none');
  plot(1:Timesteps, iSurvival*100/iSurvival(Timesteps-30),'-k', 'LineWidth', 0.5);
  plot(Timesteps-30:Timesteps, iSurvival(Timesteps-30:Timesteps)*100/iSurvival(Timesteps-30),'-k', 'LineWidth', 2);
  ylabel('Gonad size (g)','FontName',FontName,'FontSize',AxisLabelFontSize,'FontWeight',AxisLabelWeight);
  text(15,105,'Survival','FontName',FontName,'FontSize',PanelLabelFontSize,'FontWeight','bold','Color','k');
  text(25,20,'Gonads','FontName',FontName,'FontSize',PanelLabelFontSize,'FontWeight','bold','Color','w');
  axis([0 Timesteps 0 250]);
 elseif panel == 3
  area(1:Timesteps, iIntake_L/(1-SDA_L)+iIntake_P/(1-SDA_P),'FaceColor', 'b', 'LineStyle','none');
  area(1:Timesteps, iIntake_L/(1-SDA_L),'FaceColor', 'y', 'LineStyle','none');
  plot(1:Timesteps, iIntake,'-k', 'LineWidth', 1);
  plot(1:Timesteps, iMaxEvacuationRate,'-r', 'LineWidth', 1);
  ylabel('Intake (J w-1)','FontName',FontName,'FontSize',AxisLabelFontSize,'FontWeight',AxisLabelWeight);
  text(1,4e5,'Max evacuation','FontName',FontName,'FontSize',PanelLabelFontSize,'FontWeight','bold','Color','r');
  text(1,5e4,'Lipids','FontName',FontName,'FontSize',PanelLabelFontSize,'FontWeight','bold','Color','k');
  text(20,1e5,'Proteins','FontName',FontName,'FontSize',PanelLabelFontSize,'FontWeight','bold','Color','w');
 set(FigForwardPanels(panel),'YLim',[0 12e5]);
 elseif panel == 2
  plot([1 Timesteps],[maxLweight maxLweight],':k','LineWidth',1);
  area(1:Timesteps,iLweight,'FaceColor','y');
  plot(1:Timesteps,iIntake_L/LipidEnergyDensity,'-r', 'LineWidth', 1);
  plot(1:Timesteps,iARAweight(:)*10.,'-k', 'LineWidth',1);
  ylabel('Lipid store (g)','FontName',FontName,'FontSize',AxisLabelFontSize,'FontWeight',AxisLabelWeight);
  axis([0 Timesteps 0 200]);
elseif panel == 4
  plot([1 Timesteps],[maxPweight maxPweight],':k','LineWidth',1);
  area(1:Timesteps,iPweight,'FaceColor','b');
  plot(1:Timesteps,iIntake_P/ProteinEnergyDensity,'-g', 'LineWidth', 1);  %Protein intake, in green for income
  plot(1:Timesteps,iTotalPrequirement/ProteinEnergyDensity,'-r', 'LineWidth', 1);  %Protein use, in red for expenditure
  ylabel('Protein store (g)','FontName',FontName,'FontSize',AxisLabelFontSize,'FontWeight',AxisLabelWeight);
  axis([0 Timesteps 0 500]);
 elseif panel == 5
  area(1:Timesteps,100*(StructuralWeight + iPweight + iLweight + iGonadWeight)/(Length^3),'FaceColor', 'r', 'LineStyle', 'none');
  area(1:Timesteps,100*(StructuralWeight + iPweight + iLweight)/(Length^3),'FaceColor', 'y', 'LineStyle', 'none');
  area(1:Timesteps,100*(StructuralWeight + iPweight)/(Length^3),'FaceColor', 'b', 'LineStyle', 'none');
  area([1 Timesteps],[Structural_K Structural_K],'FaceColor',[0.5 0.5 0.5]);
  plot(1:Timesteps,100*(StructuralWeight + iPweight + iLweight + iGonadWeight)/(Length^3),'-k');
  ylabel('Condition (K)','FontName',FontName,'FontSize',AxisLabelFontSize,'FontWeight',AxisLabelWeight);
  axis([0 Timesteps 0.7 1.3]);
 elseif panel == 6
  area(1:Timesteps,iAMR,'FaceColor', [0.5 0.5 0.5]);
  area(1:Timesteps,iSMR+iEnergeticCostOfForaging+iGonadGrowthCost+iSDA,'FaceColor',[1 .5 0]);
  area(1:Timesteps,iSMR+iEnergeticCostOfForaging+iGonadGrowthCost,'FaceColor','r');
  area(1:Timesteps,iSMR+iEnergeticCostOfForaging,'FaceColor','g');
  area(1:Timesteps,iSMR,'FaceColor',[0.5 0.5 0.5]);
  ylabel('O2 use (J)','FontName',FontName,'FontSize',AxisLabelFontSize,'FontWeight',AxisLabelWeight);
 elseif panel == 7
  plot(1:Timesteps,iForagingRate,'Color','g', 'LineWidth',2);
  plot(1:Timesteps,2*iH,'-k');
  ylabel({'Behaviour' 'Habitat'},'FontName',FontName,'FontSize',AxisLabelFontSize,'FontWeight',AxisLabelWeight);
  text(1,5,'Herring','FontName',FontName,'FontSize',PanelLabelFontSize,'FontWeight','bold','Color','k');
  text(1,1.5,'Crabs','FontName',FontName,'FontSize',PanelLabelFontSize,'FontWeight','bold','Color','k');
  text(1,13,'Foraging behaviour','FontName',FontName,'FontSize',PanelLabelFontSize,'FontWeight','bold','Color','g');
  axis([0 Timesteps 0 15]);
elseif panel == 8
  area(1:Timesteps,iTotalLrequirement+iTotalPrequirement,'FaceColor','b', 'LineStyle', 'none');
  area(1:Timesteps,iTotalLrequirement,'FaceColor','y', 'LineStyle', 'none');
  plot(1:Timesteps,iTotalMRrequirement+iGonadGrowth,'-k');
  plot(1:Timesteps,iTotalMRrequirement,'-k');
  plot(1:Timesteps, iSMR + iEnergeticCostOfForaging,'-k');
   plot(1:Timesteps, iSMR ,'-k');
  ylabel('Nutrient use (J)','FontName',FontName,'FontSize',AxisLabelFontSize,'FontWeight',AxisLabelWeight);
 elseif panel == 9
  area(1:Timesteps,iARAweight,'FaceColor','b', 'LineStyle', 'none');
  area(1:Timesteps,iIntake_ARA,'FaceColor','y', 'LineStyle', 'none');
  area(1:Timesteps,-iMetabolizedARA-iARAflowtoGonads,'FaceColor','r', 'LineStyle', 'none');
  area(1:Timesteps,-iMetabolizedARA,'FaceColor','g', 'LineStyle', 'none');
  plot(1:Timesteps,(iARAweight./iLweight)*100,'-k');
  ylabel('ARA lipd stores (g)','FontName',FontName,'FontSize',AxisLabelFontSize,'FontWeight',AxisLabelWeight);
  axis([0 Timesteps -1 7]);
elseif panel == 10
  area(1:Timesteps,iGAweight,'FaceColor','b', 'LineStyle', 'none');
  plot(1:Timesteps,(10*iGAweight(:)./(iGonadWeight(:)*GonadEnergyDensity*(1-GonadProteinProportion)/LipidEnergyDensity)),'-k');
  ylabel('ARA gonads(g)','FontName',FontName,'FontSize',AxisLabelFontSize,'FontWeight',AxisLabelWeight);
  text(1,0.7,[num2str(100*iGAweight(Timesteps-1)/(iGonadWeight(Timesteps-1)*GonadEnergyDensity*(1-GonadProteinProportion)/LipidEnergyDensity),2),' % ARA'],'FontName',FontName,'FontSize',PanelLabelFontSize,'FontWeight','bold','Color','k');
 end
 %axis([minx maxx miny maxy]);
 if panel >= FigCols*FigRows-1.5; %Add x-axis to two lower panels
  xlabel('Time before spawning (weeks)','FontName',FontName,'FontSize',AxisLabelFontSize,'FontWeight',AxisLabelWeight);
  set(FigForwardPanels(panel),'XTick',0:5:Timesteps,'XTickLabel',Timesteps:-5:0);
 else
  set(FigForwardPanels(panel),'XTickLabel',[]);
 end
 %text(minx + 0.05*(maxx-minx),miny+0.94*(maxy-miny),PanelLabel(panel),'FontName',FontName,'FontSize',PanelLabelFontSize,'FontWeight','bold','Color','k');
 %axis square;
 grid off;
 box on;
 view(0,90);
 hold off;
end

csvwrite('OUT_DEFAULT_feast/Liver_reserves.csv',iLweight)
csvwrite('OUT_DEFAULT_feast/Foraging_behav.csv',iForagingRate)
csvwrite('OUT_DEFAULT_feast/Prey_choice.csv',iH)
csvwrite('OUT_DEFAULT_feast/Protein_stores.csv',iPweight)
csvwrite('OUT_DEFAULT_feast/Intake.csv',iIntake)
csvwrite('OUT_DEFAULT_feast/Surviv.csv',iSurvival)
csvwrite('OUT_DEFAULT_feast/IntakeL.csv',iIntake_L)
csvwrite('OUT_DEFAULT_feast/IntakeP.csv',iIntake_P)

iARAi = num2str(100*iGAweight(Timesteps-1)/(iGonadWeight(Timesteps-1)*GonadEnergyDensity*(1-GonadProteinProportion)/LipidEnergyDensity),2);
csvwrite('OUT_DEFAULT_feast/ARA.csv',iARAi);


Lr = iIntake_L./iIntake;
Pr = iIntake_P./iIntake;


Lfirst = mean(Lr(1:30))
Llast = mean(Lr(31:69))

Pfirst = mean(Pr(1:30))
Plast = mean(Pr(31:69))
